# Welcome to flaskmng

## What is flaskmng?

**flaskmng** is a tool that manages Flask project. It is designed in MVT architecture.

## Usage

First of all, you must create virtual environment.

```bash
> python -m venv env
```

To activate,

```bash
> . env/Scripts/activate # for Windows
> source env/bin/activate # for Linux
```

Then, for installing flaskmng to the virtual environment you must use pip. After installing pip enter the command given below:

```bash
> pip install flaskmng 
```

### Startproject

For creating main structure of your flask application and starting project: 

```bash
> flaskmng startproject
```

Don't forget to add your virtual environment name to .gitignore file.

### Startapp
Then, you can add multiple apps to your project. For creating single app structure:

```bash
> flaskmng startapp
```

## Conclusion
In conclusion, your flask project ready to development. Enjoy the advantages of flaskmng.

**Thanks for using!**
